"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseController = void 0;
class BaseController {
    /**
     * @param {Kuzzle} kuzzle - Kuzzle SDK object.
     * @param {string} name - Controller full name for API request.
     */
    constructor(kuzzle, name) {
        Reflect.defineProperty(this, "_kuzzle", {
            value: kuzzle,
        });
        this._name = name;
    }
    get kuzzle() {
        return this._kuzzle;
    }
    /**
     * Controller name
     */
    get name() {
        return this._name;
    }
    /**
     * Sends a query to Kuzzle.
     * If not set, the "controller" property of the request will be the controller name.
     *
     * @param request
     * @param options
     */
    query(request, options = {}) {
        request.controller = request.controller || this.name;
        return this._kuzzle.query(request, options);
    }
}
exports.BaseController = BaseController;
//# sourceMappingURL=Base.js.map